Enum diem_resource_viewer::AnnotatedMoveValue [−]
pub enum AnnotatedMoveValue {
U8(u8),
U64(u64),
U128(u128),
Bool(bool),
Address(AccountAddress),
Vector(TypeTag, Vec<AnnotatedMoveValue, Global>),
Bytes(Vec<u8, Global>),
Struct(AnnotatedMoveStruct),
}Expand description
AnnotatedMoveValue is a fully expanded version of on chain Move data. This should only be used for debugging/client purpose right now and just for a better visualization of on chain data. In the long run, we would like to transform this struct to a Json value so that we can have a cross platform interpretation of the on chain data.
Variants
U8(u8)Tuple Fields of U8
0: u8U64(u64)Tuple Fields of U64
0: u64U128(u128)Tuple Fields of U128
0: u128Bool(bool)Tuple Fields of Bool
0: boolVector(TypeTag, Vec<AnnotatedMoveValue, Global>)Tuple Fields of Vector
0: TypeTag1: Vec<AnnotatedMoveValue, Global>Struct(AnnotatedMoveStruct)Tuple Fields of Struct
Implementations
impl AnnotatedMoveValue
impl AnnotatedMoveValue
pub fn get_type(&self) -> TypeTag